Social Eating - Vizeat

# Accogli dei viaggiatori a casa tua
e vivi dei momenti unici!

Iscriviti con Facebook
Non pubblicheremo mai niente sulla tua pagina!
o

## Ritrova i Guests da tutto il mondo a tavola.

#### Cucina

Fai conoscere le tue ricette preferite, dalla più semplice alla più elaborata.

#### Conosci persone nuove

Incontra i VizEaters provenienti da tutti gli angoli del mondo come fossero tuoi vicini di casa. Sei sempre libero di accettare o rifiutare ogni richiesta di prenotazione.

#### Fissa il prezzo del menù

Puoi liberamente scegliere il prezzo che reputi più giusto per il tuo menù. Riceverai il 100% dell'importo del menù il giorno dopo l'evento.